// Copyright 2020 The TensorStore Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "tensorstore/util/quote_string.h"

#include <gtest/gtest.h>

namespace {

using ::tensorstore::QuoteString;

TEST(QuoteStringTest, Basic) {
  EXPECT_EQ("\"abc \"", QuoteString("abc "));
  EXPECT_EQ("\"a\\\"b\\n\\x01\"", QuoteString("a\"b\n\x01"));
  EXPECT_EQ("\"\\'\"", QuoteString("'"));
}

}  // namespace
